@@ -19,9 +19,7 @@ public:
     {
     }
 
-    ~KOrganizerUniqueAppHandler() override
-    {
-    }
+    ~KOrganizerUniqueAppHandler() override = default;
 
     void loadCommandLineOptions(QCommandLineParser *parser) override;
     int activate(const QStringList &args, const QString &workingDir) override;
